@@ -527,7 +527,6 @@ class OpenAssessmentBlock(MessageMixin,
             "show_staff_area": self.is_course_staff and not self.in_studio_preview,
         }
         template = get_template("openassessmentblock/oa_base.html")
-
         return self._create_fragment(template, context_dict, initialize_js_func='OpenAssessmentBlock')
 
     def ora_blocks_listing_view(self, context=None):
@@ -878,7 +877,22 @@ class OpenAssessmentBlock(MessageMixin,
 
     @property
     def assessment_steps(self):
-        return [asmnt['name'] for asmnt in self.valid_assessments]
+        """
+        Return a list of assessment steps by name.
+        Also filter out assessments that have required set to false and do not
+        contain a staff grade override.
+
+        Returns:
+            list
+
+        """
+        assessment_steps = []
+        for assessment in self.valid_assessments:
+            if assessment['name'] == 'staff-assessment' and assessment["required"] is False:
+                if not self.staff_assessment_exists(self.submission_uuid):
+                    continue
+            assessment_steps.append(assessment['name'])
+        return assessment_steps
 
     @lazy
     def rubric_criteria_with_labels(self):
